@@ -7,10 +7,7 @@ Usage::
     import boto3
     from mypy_boto3_ec2_instance_connect import EC2InstanceConnectClient
 
-    session = boto3.Session()
-
     client: EC2InstanceConnectClient = boto3.client("ec2-instance-connect")
-    session_client: EC2InstanceConnectClient = session.client("ec2-instance-connect")
     ```
 """
 # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
